@@ -4,11 +4,11 @@
 
 """
 
+from pyNN.utility import get_simulator, init_logging, normalized_filename
+import neo
+import numpy as np
 import matplotlib
 matplotlib.use('Agg')
-import numpy as np
-import neo
-from pyNN.utility import get_simulator, init_logging, normalized_filename
 
 
 # === Configure the simulator ================================================
@@ -42,17 +42,19 @@ synapse_types = {
 populations = {}
 projections = {}
 for label in synapse_types:
-    populations[label] = sim.Population(1000, sim.IF_cond_exp(e_rev_I=-75, tau_syn_I=4.3), label=label)
+    populations[label] = sim.Population(
+        1000, sim.IF_cond_exp(e_rev_I=-75, tau_syn_I=4.3), label=label)
     populations[label].record('gsyn_inh')
     projections[label] = sim.Projection(spike_source, populations[label], connector,
                                         receptor_type='inhibitory',
                                         synapse_type=synapse_types[label])
-    projections[label].initialize(a=synapse_types[label].parameter_space['n'], u=synapse_types[label].parameter_space['U'])
+    projections[label].initialize(a=synapse_types[label].parameter_space['n'],
+                                  u=synapse_types[label].parameter_space['U'])
 
 spike_source.record('spikes')
 
-if "nest" in sim.__name__:
-    print(sim.nest.GetStatus([projections['depressing, n=5'].nest_connections[0]]))
+#if "nest" in sim.__name__:
+#    print(sim.nest.GetStatus([projections['depressing, n=5'].nest_connections[0]]))
 
 # === Run the simulation =====================================================
 
@@ -69,7 +71,7 @@ for label, p in populations.items():
 
 if options.plot_figure:
     from pyNN.utility.plotting import Figure, Panel
-    #figure_filename = normalized_filename("Results", "multiquantal_synapses",
+    # figure_filename = normalized_filename("Results", "multiquantal_synapses",
     #                                      "png", options.simulator)
     figure_filename = "Results/multiquantal_synapses_{}.png".format(options.simulator)
 
@@ -79,7 +81,7 @@ if options.plot_figure:
         gsyn = data[label].filter(name='gsyn_inh')[0]
         gsyn_mean = neo.AnalogSignal(gsyn.mean(axis=1).reshape(-1, 1),
                                      sampling_rate=gsyn.sampling_rate,
-                                     channel_index=np.array([0]))
+                                     array_annotations={"channel_index": np.array([0])})
         gsyn_mean.name = 'gsyn_inh_mean'
         data[label].analogsignals.append(gsyn_mean)
 
