@@ -24,9 +24,8 @@ optional arguments:
 
 """
 
-from __future__ import division
 from math import exp
-import numpy
+import numpy as np
 import neo
 from quantities import ms
 from pyNN.utility import get_simulator, init_logging, normalized_filename
@@ -54,8 +53,10 @@ delay = 3.0              # (ms) synaptic time delay
 # === Configure the simulator ===============================================
 
 sim, options = get_simulator(("--plot-figure", "Plot the simulation results to a file", {"action": "store_true"}),
-                             ("--fit-curve", "Calculate the best-fit curve to the weight-delta_t measurements", {"action": "store_true"}),
-                             ("--dendritic-delay-fraction", "What fraction of the total transmission delay is due to dendritic propagation", {"default": 1}),
+                             ("--fit-curve", "Calculate the best-fit curve to the weight-delta_t measurements",
+                              {"action": "store_true"}),
+                             ("--dendritic-delay-fraction",
+                              "What fraction of the total transmission delay is due to dendritic propagation", {"default": 1}),
                              ("--debug", "Print debugging information"))
 
 if options.debug:
@@ -74,9 +75,10 @@ def build_spike_sequences(period, duration, n, delta_t):
     """
     def spike_time_gen(i):
         """Spike time generator. `i` should be an array of indices."""
-        return [Sequence(numpy.arange(period + j * delta_t, duration, period)) for j in (i - n // 2)]
+        return [Sequence(np.arange(period + j * delta_t, duration, period)) for j in (i - n // 2)]
     return spike_time_gen
 
+
 spike_sequence_generator = build_spike_sequences(firing_period, t_stop, n, delta_t)
 # presynaptic population
 p1 = sim.Population(n, sim.SpikeSourceArray(spike_times=spike_sequence_generator),
@@ -85,18 +87,18 @@ p1 = sim.Population(n, sim.SpikeSourceArray(spike_times=spike_sequence_generator
 p2 = sim.Population(1, sim.IF_cond_exp(**cell_parameters),
                     initial_values={"v": cell_parameters["v_reset"]}, label="postsynaptic")
 # drive to the postsynaptic neuron, ensuring it fires at exact multiples of the firing period
-p3 = sim.Population(1, sim.SpikeSourceArray(spike_times=numpy.arange(firing_period - delay, t_stop, firing_period)),
+p3 = sim.Population(1, sim.SpikeSourceArray(spike_times=np.arange(firing_period - delay, t_stop, firing_period)),
                     label="driver")
 
 # we set the initial weights to be very small, to avoid perturbing the firing times of the
 # postsynaptic neurons
 stdp_model = sim.STDPMechanism(
-                timing_dependence=sim.SpikePairRule(tau_plus=20.0, tau_minus=20.0,
-                                                    A_plus=0.01, A_minus=0.012),
-                weight_dependence=sim.AdditiveWeightDependence(w_min=0, w_max=0.0000001),
-                weight=0.00000005,
-                delay=delay,
-                dendritic_delay_fraction=float(options.dendritic_delay_fraction))
+    timing_dependence=sim.SpikePairRule(tau_plus=20.0, tau_minus=20.0,
+                                        A_plus=0.01, A_minus=0.012),
+    weight_dependence=sim.AdditiveWeightDependence(w_min=0, w_max=0.0000001),
+    weight=0.00000005,
+    delay=delay,
+    dendritic_delay_fraction=float(options.dendritic_delay_fraction))
 connections = sim.Projection(p1, p2, sim.AllToAllConnector(), stdp_model)
 
 # the connection weight from the driver neuron is very strong, to ensure the
@@ -128,10 +130,10 @@ class WeightRecorder(object):
 
     def get_weights(self):
         signal = neo.AnalogSignal(self._weights, units='nA', sampling_period=self.interval * ms,
-                                  name="weight")
-        signal.channel_index = neo.ChannelIndex(numpy.arange(len(self._weights[0])))
+                                  name="weight", array_annotations={"channel_index": np.arange(len(self._weights[0]))})
         return signal
 
+
 weight_recorder = WeightRecorder(sampling_interval=1.0, projection=connections)
 
 # === Run the simulation =====================================================
@@ -149,15 +151,15 @@ postsynaptic_data = p2.get_data().segments[0]
 print("Post-synaptic spike times: %s" % postsynaptic_data.spiketrains[0])
 
 weights = weight_recorder.get_weights()
-final_weights = numpy.array(weights[-1])
-deltas = delta_t * numpy.arange(n // 2, -n // 2, -1)
+final_weights = np.array(weights[-1])
+deltas = delta_t * np.arange(n // 2, -n // 2, -1)
 print("Final weights: %s" % final_weights)
 plasticity_data = DataTable(deltas, final_weights)
 
 
 if options.fit_curve:
     def double_exponential(t, t0, w0, wp, wn, tau):
-        return w0 + numpy.where(t >= t0, wp * numpy.exp(-(t - t0) / tau), wn * numpy.exp((t - t0) / tau))
+        return w0 + np.where(t >= t0, wp * np.exp(-(t - t0) / tau), wn * np.exp((t - t0) / tau))
     p0 = (-1.0, 5e-8, 1e-8, -1.2e-8, 20.0)
     popt, pcov = plasticity_data.fit_curve(double_exponential, p0, ftol=1e-10)
     print("Best fit parameters: t0={0}, w0={1}, wp={2}, wn={3}, tau={4}".format(*popt))
