@@ -76,9 +76,9 @@ if options.plot_figure:
         if 'stochastic' in label:
             gsyn = data[label].filter(name='gsyn_inh')[0]
             gsyn_mean = neo.AnalogSignal(gsyn.mean(axis=1).reshape(-1, 1),
-                                         sampling_rate=gsyn.sampling_rate)
-            gsyn_mean.channel_index = neo.ChannelIndex(np.array([0]))
-            gsyn_mean.name = 'gsyn_inh_mean'
+                                         sampling_rate=gsyn.sampling_rate,
+                                         array_annotations={"channel_index": np.array([0])},
+                                         name = 'gsyn_inh_mean')
             data[label].analogsignals.append(gsyn_mean)
 
     def make_panel(population, label):
