@@ -33,7 +33,7 @@ def plot_signal(panel, signal, index, colour='b', linewidth='1', label='', fake_
         v_thresh = fake_aps
         spike_indices = signal >= v_thresh - 0.05 * mV
         signal[spike_indices] = 0.0 * mV
-    panel.plot(signal.times, signal[:, index], colour, linewidth=linewidth, label=label)
+    panel.plot(signal.times, signal.magnitude[:, index], colour, linewidth=linewidth, label=label)
     #plt.setp(plt.gca().get_xticklabels(), visible=False)
     if not hide_axis_labels:
         panel.set_xlabel("time (%s)" % signal.times.units._dimensionality.string)
@@ -47,7 +47,7 @@ def plot_hist(panel, hist, bins, width, xlabel=None, ylabel=None,
     if ylabel:
         panel.set_ylabel(ylabel)
     for t, n in zip(bins[:-1], hist):
-        panel.bar(t, n, width=width, color=None)
+        panel.bar(t, n, width=width, color='b')
     if xmin:
         panel.set_xlim(xmin=xmin)
     if ymax:
@@ -73,9 +73,8 @@ def plot_vm_traces(panel, segment, label, hide_axis_labels=False):
 
 def plot_spiketrains(panel, segment, label, hide_axis_labels=False):
     print("plotting spikes for %s" % label)
-    for spiketrain in segment.spiketrains:
-        y = np.ones_like(spiketrain) * spiketrain.annotations['source_id']
-        panel.plot(spiketrain, y, '.', markersize=0.2)
+    channel_ids, spike_times = segment.spiketrains.multiplexed
+    panel.plot(channel_ids, spike_times, '.', markersize=0.2)
     if not hide_axis_labels:
         panel.set_ylabel(segment.name)
     #plt.setp(plt.gca().get_xticklabels(), visible=False)
