@@ -15,7 +15,7 @@ Attributes:
 All other functions and classes are private, and should not be used by other
 modules.
 
-:copyright: Copyright 2006-2021 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2022 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 
 """
@@ -58,13 +58,20 @@ def load_mechanisms(path):
         return
     # in case NEURON is assuming a different architecture to Python,
     # we try multiple possibilities
-    arch_list = [platform.machine(), 'i686', 'x86_64', 'powerpc', 'umac']
-    for arch in arch_list:
-        lib_path = os.path.join(path, arch, '.libs', 'libnrnmech.so')
+    if platform.system() == 'Windows':
+        lib_path = os.path.join(path, 'nrnmech.dll')
         if os.path.exists(lib_path):
             h.nrn_load_dll(lib_path)
             nrn_dll_loaded.append(path)
             return
+    else:
+        arch_list = [platform.machine(), 'i686', 'x86_64', 'powerpc', 'umac']
+        for arch in arch_list:
+            lib_path = os.path.join(path, arch, '.libs', 'libnrnmech.so')
+            if os.path.exists(lib_path):
+                h.nrn_load_dll(lib_path)
+                nrn_dll_loaded.append(path)
+                return
     raise IOError("NEURON mechanisms not found in %s. You may need to run 'nrnivmodl' in this directory." % path)
 
 
@@ -165,6 +172,7 @@ class _State(common.control.BaseState):
         self.clear()
         self.default_maxstep = 10.0
         self.native_rng_baseseed = 0
+        self.record_sample_times = False
 
     t = h_property('t')
 
