@@ -1,12 +1,15 @@
 """
 Parameter set handling
 
-:copyright: Copyright 2006-2021 by the PyNN team, see AUTHORS.
+:copyright: Copyright 2006-2022 by the PyNN team, see AUTHORS.
 :license: CeCILL, see LICENSE for details.
 """
 
 import numpy as np
-import collections
+try:
+    from collections import Sized
+except ImportError:
+    from collections.abc import Sized
 from pyNN.core import is_listlike
 from pyNN import errors
 from pyNN.random import RandomDistribution, NativeRNG
@@ -296,11 +299,11 @@ class ParameterSpace(object):
                     raise errors.NonExistentParameterError(name,
                                                            model_name,
                                                            valid_parameter_names=self.schema.keys())
-                if issubclass(expected_dtype, ArrayParameter) and isinstance(value, collections.Sized):
+                if issubclass(expected_dtype, ArrayParameter) and isinstance(value, Sized):
                     if len(value) == 0:
                         value = ArrayParameter([])
                     elif not isinstance(value[0], ArrayParameter):  # may be a more generic way to do it, but for now this special-casing seems like the most robust approach
-                        if isinstance(value[0], collections.Sized):  # e.g. list of tuples
+                        if isinstance(value[0], Sized):  # e.g. list of tuples
                             value = type(value)([ArrayParameter(x) for x in value])
                         else:
                             value = ArrayParameter(value)
