@@ -2,7 +2,6 @@
 from nose.plugins.skip import SkipTest
 from numpy.testing import assert_array_almost_equal
 
-import pyNN.nest as sim
 from pyNN.random import RandomDistribution as RD
 from pyNN.network import Network
 from pyNN.serialization import export_to_sonata, import_from_sonata, asciify
@@ -13,9 +12,15 @@ try:
 except ImportError:
     HAVE_H5PY = False
 
+try:
+    import pyNN.nest as sim
+    HAVE_NEST = True
+except ImportError:
+    HAVE_NEST = False
+
 
 def test():
-    if not HAVE_H5PY:
+    if not HAVE_H5PY and HAVE_NEST:
         raise SkipTest
 
     sim.setup()
@@ -33,10 +38,10 @@ def test():
                         label="population_two")
 
     prj = sim.Projection(p1, p2,
-                        sim.FixedProbabilityConnector(p_connect=0.5),
-                        synapse_type=sim.StaticSynapse(weight=RD('uniform', [0.0, 0.1]),
+                         sim.FixedProbabilityConnector(p_connect=0.5),
+                         synapse_type=sim.StaticSynapse(weight=RD('uniform', [0.0, 0.1]),
                                                         delay=0.5),
-                        receptor_type='excitatory')
+                         receptor_type='excitatory')
 
     net = Network(p1, p2, prj)
 
@@ -44,7 +49,6 @@ def test():
 
     net2 = import_from_sonata("tmp_serialization_test/circuit_config.json", sim)
 
-
     for orig_population in net.populations:
         imp_population = net2.get_component(orig_population.label)
         assert orig_population.size == imp_population.size
@@ -58,4 +62,4 @@ def test():
 
 
 if __name__ == "__main__":
-    test()
\ No newline at end of file
+    test()
