@@ -1,10 +1,7 @@
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 from pyNN import common, errors, random, standardmodels, space, descriptions
-import numpy
+import numpy as np
 try:
     from unittest.mock import Mock
 except ImportError:
