@@ -4,15 +4,8 @@ try:
 except ImportError:
     nest = False
 from pyNN.standardmodels import StandardCellType
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-try:
-    basestring
-except NameError:
-    basestring = str
-import numpy
+import unittest
+import numpy as np
 from numpy.testing import assert_array_equal, assert_array_almost_equal
 
 
@@ -25,23 +18,19 @@ class TestFunctions(unittest.TestCase):
     def test_list_standard_models(self):
         cell_types = sim.list_standard_models()
         self.assertTrue(len(cell_types) > 10)
-        self.assertIsInstance(cell_types[0], basestring)
+        self.assertIsInstance(cell_types[0], str)
 
     def test_setup(self):
         sim.setup(timestep=0.05, min_delay=0.1, max_delay=1.0,
                   verbosity='debug', spike_precision='off_grid',
-                  recording_precision=4, threads=2, rng_seeds=[873465, 3487564])
+                  recording_precision=4, threads=2, rng_seed=873465)
         ks = nest.GetKernelStatus()
         self.assertEqual(ks['resolution'], 0.05)
         self.assertEqual(ks['local_num_threads'], 2)
-        self.assertEqual(ks['rng_seeds'], (873465, 3487564))
+        self.assertEqual(ks['rng_seed'], 873465)
         #self.assertEqual(ks['min_delay'], 0.1)
         #self.assertEqual(ks['max_delay'], 1.0)
-        self.assertTrue(ks['off_grid_spiking'])
-
-    def test_setup_with_rng_seeds(self):
-        sim.setup(rng_seeds_seed=42, threads=3)
-        self.assertEqual(len(nest.GetKernelStatus('rng_seeds')), 3)
+        self.assertEqual(sim.state.spike_precision, "off_grid")
 
     def test_run_0(self, ):  # see https://github.com/NeuralEnsemble/PyNN/issues/191
         sim.setup(timestep=0.123, min_delay=0.246)
@@ -56,7 +45,7 @@ class TestPopulation(unittest.TestCase):
         sim.setup()
         self.p = sim.Population(4, sim.IF_cond_exp(**{'tau_m': 12.3,
                                                       'cm': lambda i: 0.987 + 0.01 * i,
-                                                      'i_offset': numpy.array([-0.21, -0.20, -0.19, -0.18])}))
+                                                      'i_offset': np.array([-0.21, -0.20, -0.19, -0.18])}))
 
     def test_create_native(self):
         cell_type = sim.native_cell_type('iaf_psc_alpha')
@@ -65,9 +54,9 @@ class TestPopulation(unittest.TestCase):
     def test__get_parameters(self):
         ps = self.p._get_parameters('C_m', 'g_L', 'E_ex', 'I_e')
         ps.evaluate(simplify=True)
-        assert_array_almost_equal(ps['C_m'], numpy.array([987, 997, 1007, 1017], float),
+        assert_array_almost_equal(ps['C_m'], np.array([987, 997, 1007, 1017], float),
                                   decimal=12)
-        assert_array_almost_equal(ps['I_e'], numpy.array([-210, -200, -190, -180], float),
+        assert_array_almost_equal(ps['I_e'], np.array([-210, -200, -190, -180], float),
                                   decimal=12)
         self.assertEqual(ps['E_ex'], 0.0)
 
@@ -141,7 +130,7 @@ class TestProjection(unittest.TestCase):
     def test_set_array(self):
         weight = 0.123
         prj = sim.Projection(self.p1, self.p2, sim.AllToAllConnector())
-        weight_array = numpy.ones(prj.shape) * weight
+        weight_array = np.ones(prj.shape) * weight
         prj.set(weight=weight_array)
         self.assertTrue((weight_array == prj.get("weight", format="array")).all())
 
@@ -153,7 +142,7 @@ class TestProjection(unittest.TestCase):
         prj.set(weight=weight)
         self.assertEqual(prj.get("weight", format="array")[0], weight)
 
-        weight_array = numpy.ones(prj.shape) * weight
+        weight_array = np.ones(prj.shape) * weight
         prj.set(weight=weight_array)
         self.assertTrue((weight_array == prj.get("weight", format="array")).all())
 
@@ -165,7 +154,7 @@ class TestProjection(unittest.TestCase):
         prj.set(weight=weight)
         self.assertEqual(prj.get("weight", format="array")[0][0], weight)
 
-        weight_array = numpy.ones(prj.shape) * weight
+        weight_array = np.ones(prj.shape) * weight
         prj.set(weight=weight_array)
         self.assertTrue((weight_array == prj.get("weight", format="array")).all())
 
@@ -177,7 +166,7 @@ class TestProjection(unittest.TestCase):
         prj.set(weight=weight)
         self.assertEqual(prj.get("weight", format="array")[0][0], weight)
 
-        weight_array = numpy.ones(prj.shape) * weight
+        weight_array = np.ones(prj.shape) * weight
         prj.set(weight=weight_array)
         self.assertTrue((weight_array == prj.get("weight", format="array")).all())
 
@@ -191,7 +180,7 @@ class TestProjection(unittest.TestCase):
             weight=0.5, delay=1.0, dendritic_delay_fraction=1.0)
         prj = sim.Projection(self.p1, self.p2, self.all2all,
                              synapse_type=stdp_model)
-        actual_tau_minus = nest.GetStatus([prj.post[0]], "tau_minus")[0]
+        actual_tau_minus = nest.GetStatus(prj.post.node_collection[0], "tau_minus")[0]
         self.assertEqual(intended_tau_minus, actual_tau_minus)
 
 
