@@ -380,7 +380,7 @@ class TestRecorder(unittest.TestCase):
     #    self.rv.recorded['v'] = self.cells
     #    self.cells[0]._cell.vtrace = np.arange(-65.0, -64.0, 0.1)
     #    self.cells[1]._cell.vtrace = np.arange(-64.0, -65.0, -0.1)
-    #    self.cells[0]._cell.record_times = self.cells[1]._cell.record_times = np.arange(0.0, 1.0, 0.1)
+    #    self.cells[0]._cell.recorded_times = self.cells[1]._cell.recorded_times = np.arange(0.0, 1.0, 0.1)
     #    simulator.state.t = simulator.state.dt * len(self.cells[0]._cell.vtrace)
     #    vdata = self.rv._get_current_segment(variables=['v'], filter_ids=None)
     #    self.assertEqual(len(vdata.analogsignals), 1)
@@ -389,12 +389,12 @@ class TestRecorder(unittest.TestCase):
 
     def test__get_spikes(self):
         self.rec.recorded['spikes'] = self.cells
-        self.cells[0]._cell.spike_times = np.arange(101.0, 111.0)
-        self.cells[1]._cell.spike_times = np.arange(13.0, 23.0)
+        self.cells[0]._cell.spike_times.from_python(np.arange(101.0, 111.0))
+        self.cells[1]._cell.spike_times.from_python(np.arange(13.0, 23.0))
         simulator.state.t = 111.0
         sdata = self.rec._get_current_segment(variables=['spikes'], filter_ids=None)
         self.assertEqual(len(sdata.spiketrains), 2)
-        assert_array_equal(np.array(sdata.spiketrains[0]), self.cells[0]._cell.spike_times)
+        assert_array_equal(np.array(sdata.spiketrains[0]), self.cells[0]._cell.spike_times.as_numpy())
 
     # def test__get_gsyn(self):
     #    self.rg.recorded['gsyn_exc'] = self.cells
@@ -405,7 +405,7 @@ class TestRecorder(unittest.TestCase):
     #        cell._cell.gsyn_trace['inhibitory'] = np.arange(1.01, 1.0199, 0.001)
     #        cell._cell.gsyn_trace['excitatory_TM'] = np.arange(2.01, 2.0199, 0.001)
     #        cell._cell.gsyn_trace['inhibitory_TM'] = np.arange(4.01, 4.0199, 0.001)
-    #        cell._cell.record_times = self.cells[1]._cell.record_times = np.arange(0.0, 1.0, 0.1)
+    #        cell._cell.recorded_times = self.cells[1]._cell.recorded_times = np.arange(0.0, 1.0, 0.1)
     #    simulator.state.t = simulator.state.dt * len(cell._cell.gsyn_trace['excitatory'])
     #    gdata = self.rg._get_current_segment(variables=['gsyn_exc', 'gsyn_inh'], filter_ids=None)
     #    self.assertEqual(len(gdata.analogsignals), 2)
